@@ -7,7 +7,7 @@ use std::{
 use fs_err as fs;
 
 use crate::{
-    commands::warn_user_about_loading_zip_in_memory,
+    commands::{warn_user_about_loading_sevenz_in_memory, warn_user_about_loading_zip_in_memory},
     extension::{
         split_first_compression_format,
         CompressionFormat::{self, *},
@@ -82,11 +82,11 @@ pub fn decompress_file(
         let decoder: Box<dyn Read> = match format {
             Gzip => Box::new(flate2::read::GzDecoder::new(decoder)),
             Bzip => Box::new(bzip2::read::BzDecoder::new(decoder)),
-            Lz4 => Box::new(lzzzz::lz4f::ReadDecompressor::new(decoder)?),
+            Lz4 => Box::new(lz4_flex::frame::FrameDecoder::new(decoder)),
             Lzma => Box::new(xz2::read::XzDecoder::new(decoder)),
             Snappy => Box::new(snap::read::FrameDecoder::new(decoder)),
             Zstd => Box::new(zstd::stream::Decoder::new(decoder)?),
-            Tar | Zip => unreachable!(),
+            Tar | Zip | Rar | SevenZip => unreachable!(),
         };
         Ok(decoder)
     };
@@ -146,6 +146,47 @@ pub fn decompress_file(
                 return Ok(());
             }
         }
+        Rar => {
+            type UnpackResult = crate::Result<usize>;
+            let unpack_fn: Box<dyn FnOnce(&Path) -> UnpackResult> = if formats.len() > 1 {
+                let mut temp_file = tempfile::NamedTempFile::new()?;
+                io::copy(&mut reader, &mut temp_file)?;
+                Box::new(move |output_dir| crate::archive::rar::unpack_archive(temp_file.path(), output_dir, quiet))
+            } else {
+                Box::new(|output_dir| crate::archive::rar::unpack_archive(input_file_path, output_dir, quiet))
+            };
+
+            if let ControlFlow::Continue(files) =
+                smart_unpack(unpack_fn, output_dir, &output_file_path, question_policy)?
+            {
+                files
+            } else {
+                return Ok(());
+            }
+        }
+        SevenZip => {
+            if formats.len() > 1 {
+                warn_user_about_loading_sevenz_in_memory();
+
+                if !user_wants_to_continue(input_file_path, question_policy, QuestionAction::Decompression)? {
+                    return Ok(());
+                }
+            }
+
+            let mut vec = vec![];
+            io::copy(&mut reader, &mut vec)?;
+
+            if let ControlFlow::Continue(files) = smart_unpack(
+                |output_dir| crate::archive::sevenz::decompress_sevenz(io::Cursor::new(vec), output_dir, quiet),
+                output_dir,
+                &output_file_path,
+                question_policy,
+            )? {
+                files
+            } else {
+                return Ok(());
+            }
+        }
     };
 
     // this is only printed once, so it doesn't result in much text. On the other hand,
